@@ -32,8 +32,8 @@ func formatTitle(title []byte) []byte {
 	copy(ansi[0:4], []byte{27, ']', '2', ';'})
 	copy(ansi[4:len(title)+4], title)
 	//ansi[len(ansi)-1] = 7
-	ansi[len(ansi)-2] = 'S'
-	ansi[len(ansi)-1] = 'T'
+	ansi[len(ansi)-2] = 27
+	ansi[len(ansi)-1] = '\\'
 
 	return ansi
 }
@@ -57,8 +57,8 @@ func formatIcon(title []byte) []byte {
 	copy(ansi[0:4], []byte{27, ']', '1', ';'})
 	copy(ansi[4:len(title)+4], title)
 	//ansi[len(ansi)-1] = 7
-	ansi[len(ansi)-2] = 'S'
-	ansi[len(ansi)-1] = 'T'
+	ansi[len(ansi)-2] = 27
+	ansi[len(ansi)-1] = '\\'
 
 	return ansi
 }
